==> 0.0.9.tar.gz: lib/component/multiple_image_view.dart <==
import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/net/http_api.dart';
import 'package:vone_ipfs/pages/image_picker_dialog.dart';
import 'package:vone_ipfs/pages/online_file_page.dart';
import 'package:vone_ipfs/pages/upload_progress_dialog.dart';
import 'package:vone_ipfs/utils/ifps_dialog_utils.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/component/vone_image.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';

import 'defult_upload_view.dart';
import 'intrinsic_grid_view.dart';

///
/// 多图片上传
///
class MultipleImageView extends StatefulWidget {
  ///图片的宽度
  final double imageWidth;

  ///图片高度
  final double imageHeight;

  ///已有的图片列表
  final List<UploadResultEntity> images;

  ///图片形状
  final ImageShape shape;

  ///上传成功的回调
  final ValueChanged<List<UploadResultEntity>>? valueChangedCallback;

  ///添加图片的按钮
  final Widget? addImageWidget;

  /// 添加图片按钮的位置
  final UploadBtnPosition btnPosition;
  final int itemCount;
  final String dirId;
  final String dirName;
  final String placeholder;
  final bool isFixedDir;
  final bool isCanEdit;
  final IPFSFileType fileType;

  MultipleImageView(
      {Key? key,
      this.imageWidth = 110,
      this.imageHeight = 110,
      required this.images,
      this.valueChangedCallback,
      this.addImageWidget,
      this.itemCount = 3,
      this.placeholder = '',
      this.isCanEdit = true,
      this.fileType = IPFSFileType.image,
      required this.dirId,
      required this.dirName,
      required this.isFixedDir,
      this.btnPosition = UploadBtnPosition.RIGHT,
      this.shape = ImageShape.None})
      : super(key: key);

  @override
  MultipleImageViewState createState() => new MultipleImageViewState();
}

class MultipleImageViewState extends State<MultipleImageView> {
  List<UploadResultEntity> _imageList = [];
  bool _showProgress = false;
  int _count = 0;
  int _total = 0;

  _dismissDialog() {
    Navigator.of(context).pop();
    setState(() {
      _showProgress = false;
    });
  }

  @override
  Widget build(BuildContext context) {
    int size = _imageList.length;
    if (widget.isCanEdit) {
      size = size + 1;
    }
    return Container(
      margin: const EdgeInsets.only(left: 10),
      child: Column(
        children: [
          widget.btnPosition == UploadBtnPosition.TOP
              ? _buildTopBtn()
              : const Text(''),
          IntrinsicGridView.vertical(
            children: [for (int i = 0; i < size; i++) _buildItem(i)],
            columnCount: widget.itemCount,
            horizontalSpace: 5,
            verticalSpace: 5,
          )
        ],
      ),
    );
  }

  Widget _buildItem(int index) {
    if (_imageList.isEmpty || index == _imageList.length) {
      return widget.btnPosition == UploadBtnPosition.TOP
          ? const Text('')
          : InkWell(
              child: widget.addImageWidget ??
                  DefaultUploadView(
                    width: widget.imageWidth,
                    height: widget.imageHeight,
                  ),
              onTap: () {
                _showPickerDialog();
              },
            );
    } else {
      return Container(
        width: widget.imageWidth,
        height: widget.imageHeight,
        alignment: Alignment.topLeft,
        child: Stack(
          alignment: Alignment.topRight,
          children: [
            VoneImage(
              imageWidth: double.infinity,
              imageHeight: double.infinity,
              imageUrl: _imageList[index].coverPath.isEmpty
                  ? _imageList[index].filePath
                  : _imageList[index].coverPath,
              shape: widget.shape,
              placeholder: widget.placeholder,
              boxFit: BoxFit.fill,
            ),
            Visibility(
              child: InkWell(
                child: Container(
                  width: 20,
                  height: 20,
                  decoration: BoxDecoration(
                      color: Colors.black.withOpacity(0.6),
                      borderRadius: BorderRadius.circular(14)),
                  child: const Icon(
                    Icons.close,
                    size: 20,
                    color: Colors.white,
                  ),
                ),
                onTap: () {
                  setState(() {
                    _imageList.removeAt(index);
                  });
                  if (widget.valueChangedCallback != null) {
                    widget.valueChangedCallback!(_imageList);
                  }
                },
              ),
              visible: widget.isCanEdit,
            )
          ],
        ),
      );
    }
  }

  @override
  void initState() {
    super.initState();
    _imageList = widget.images;
  }

  _showPickerDialog() {
    showModalBottomSheet(
        backgroundColor: Colors.transparent,
        context: context, //state.context,
        builder: (BuildContext context) {
          return ImagePickerDialog(
            localCallback: () {
              if (widget.isFixedDir) {
                _uploadImage();
              } else {
                IPFSDialog.showImageUpload(
                    context,
                    widget.imageWidth,
                    widget.imageHeight,
                    widget.dirId,
                    widget.dirName,
                    UploadMode.MULTIPLE,
                    widget.fileType, (value) {
                  _imageList.addAll(value);
                  if (widget.valueChangedCallback != null) {
                    widget.valueChangedCallback!(_imageList);
                  }
                  setState(() {});
                });
              }

              // IPFSUtils.instance!.fileUploadSingle(context, (value) {
              //   String url = IPFSUtils.instance!.getFilePath(value.id,value.path);
              //   _imageList.add(url);
              //   setState(() {});
              //   if (widget.valueChangedCallback != null) {
              //     widget.valueChangedCallback!(_imageList);
              //   }
              //   _dismissDialog();
              // },widget.dirId, progressCallback: (count, total) {
              //   if (!_showProgress) {
              //     _showUploadDialog();
              //     setState(() {
              //       _showProgress = true;
              //     });
              //   }
              //   setState(() {
              //     _count = count;
              //     _total = total;
              //   });
              // });
            },
            cloudCallback: () {
              Navigator.push(context, MaterialPageRoute(builder: (context) {
                return OnlineFilePage(
                  widget.dirId,
                  widget.dirName,
                  (result) {
                    setState(() {
                      if (result.isNotEmpty) {
                        result.forEach((element) {
                          _imageList.add(UploadResultEntity(
                              IPFSUtils.instance!.getFilePath(
                                  element.id, element.fileName),
                              "",
                              element.fileName));
                        });
                        if (widget.valueChangedCallback != null) {
                          widget.valueChangedCallback!(_imageList);
                        }
                        setState(() {});
                      }
                    });
                  },
                  fileType: widget.fileType,
                );
              }));
            },
          );
        });
  }

  _showUploadDialog() {
    if (_showProgress) {
      return;
    }
    print("------ $_count");
    showGeneralDialog(
        context: context,
        barrierLabel: "",
        barrierColor: Colors.black.withOpacity(0.5),
        transitionDuration: const Duration(milliseconds: 500),
        barrierDismissible: true,
        pageBuilder: (BuildContext context, Animation animation,
            Animation secondaryAnimation) {
          return Scaffold(
            backgroundColor: Colors.transparent,
            body: Center(
              child: UploadProgressDialog(
                count: _count,
                total: _total,
              ),
            ),
          );
        });
  }

  Widget _buildTopBtn() {
    return InkWell(
      child: Container(
        alignment: Alignment.center,
        width: double.infinity,
        padding: const EdgeInsets.symmetric(vertical: 15),
        margin: const EdgeInsets.only(top: 10, bottom: 10, right: 10),
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(3), color: Colors.blue),
        child: const Text(
          '选择图片',
          style: TextStyle(color: Colors.white, fontSize: 15),
        ),
      ),
      onTap: widget.isCanEdit
          ? () {
              _showPickerDialog();
            }
          : null,
    );
  }

  void _uploadImage() {
    IPFSUtils.instance!.imageUpload(context, (value) {
      _imageList.add(value);
      if (widget.valueChangedCallback != null) {
        widget.valueChangedCallback!(_imageList);
      }
      setState(() {});
    }, widget.dirId);
  }
}

==> 0.0.10.tar.gz: lib/component/multiple_image_view.dart <==
import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/net/http_api.dart';
import 'package:vone_ipfs/pages/image_picker_dialog.dart';
import 'package:vone_ipfs/pages/online_file_page.dart';
import 'package:vone_ipfs/pages/upload_progress_dialog.dart';
import 'package:vone_ipfs/utils/ifps_dialog_utils.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/component/vone_image.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';

import 'defult_upload_view.dart';
import 'intrinsic_grid_view.dart';

///
/// 多图片上传
///
class MultipleImageView extends StatefulWidget {
  ///图片的宽度
  final double imageWidth;

  ///图片高度
  final double imageHeight;

  ///已有的图片列表
  final List<UploadResultEntity> images;

  ///图片形状
  final ImageShape shape;

  ///上传成功的回调
  final ValueChanged<List<UploadResultEntity>>? valueChangedCallback;

  ///添加图片的按钮
  final Widget? addImageWidget;

  /// 添加图片按钮的位置
  final UploadBtnPosition btnPosition;
  final int itemCount;
  final String dirId;
  final String dirName;
  final String placeholder;
  final bool isFixedDir;
  final bool isCanEdit;
  final IPFSFileType fileType;

  MultipleImageView(
      {Key? key,
      this.imageWidth = 110,
      this.imageHeight = 110,
      required this.images,
      this.valueChangedCallback,
      this.addImageWidget,
      this.itemCount = 3,
      this.placeholder = '',
      this.isCanEdit = true,
      this.fileType = IPFSFileType.image,
      required this.dirId,
      required this.dirName,
      required this.isFixedDir,
      this.btnPosition = UploadBtnPosition.RIGHT,
      this.shape = ImageShape.None})
      : super(key: key);

  @override
  MultipleImageViewState createState() => new MultipleImageViewState();
}

class MultipleImageViewState extends State<MultipleImageView> {
  List<UploadResultEntity> _imageList = [];
  // bool _showProgress = false;
  // int _count = 0;
  // int _total = 0;
  @override
  Widget build(BuildContext context) {
    if (widget.images.isNotEmpty && _imageList.isEmpty) {
      _imageList = widget.images;
      widget.images.clear();
    }
    int size = _imageList.length;
    if (widget.isCanEdit) {
      size = size + 1;
    }
    return Container(
      margin: const EdgeInsets.only(left: 10),
      child: Column(
        children: [
          widget.btnPosition == UploadBtnPosition.TOP
              ? _buildTopBtn()
              : const Text(''),
          IntrinsicGridView.vertical(
            children: [for (int i = 0; i < size; i++) _buildItem(i)],
            columnCount: widget.itemCount,
            horizontalSpace: 5,
            verticalSpace: 5,
          )
        ],
      ),
    );
  }

  Widget _buildItem(int index) {
    if (_imageList.isEmpty || index == _imageList.length) {
      return widget.btnPosition == UploadBtnPosition.TOP
          ? const Text('')
          : InkWell(
              child: widget.addImageWidget ??
                  DefaultUploadView(
                    width: widget.imageWidth,
                    height: widget.imageHeight,
                  ),
              onTap: () {
                _showPickerDialog();
              },
            );
    } else {
      return Container(
        width: widget.imageWidth,
        height: widget.imageHeight,
        alignment: Alignment.topLeft,
        child: Stack(
          alignment: Alignment.topRight,
          children: [
            VoneImage(
              imageWidth: double.infinity,
              imageHeight: double.infinity,
              imageUrl: _imageList[index].coverPath.isEmpty
                  ? _imageList[index].filePath
                  : _imageList[index].coverPath,
              shape: widget.shape,
              placeholder: widget.placeholder,
              boxFit: BoxFit.fill,
            ),
            Visibility(
              child: InkWell(
                child: Container(
                  width: 20,
                  height: 20,
                  decoration: BoxDecoration(
                      color: Colors.black.withOpacity(0.6),
                      borderRadius: BorderRadius.circular(14)),
                  child: const Icon(
                    Icons.close,
                    size: 20,
                    color: Colors.white,
                  ),
                ),
                onTap: () {
                  setState(() {
                    _imageList.removeAt(index);
                  });
                  if (widget.valueChangedCallback != null) {
                    widget.valueChangedCallback!(_imageList);
                  }
                },
              ),
              visible: widget.isCanEdit,
            )
          ],
        ),
      );
    }
  }

  @override
  void initState() {
    super.initState();
  }

  _showPickerDialog() {
    showModalBottomSheet(
        backgroundColor: Colors.transparent,
        context: context, //state.context,
        builder: (BuildContext context) {
          return ImagePickerDialog(
            localCallback: () {
              if (widget.isFixedDir) {
                _uploadImage();
              } else {
                IPFSDialog.showImageUpload(
                    context,
                    widget.imageWidth,
                    widget.imageHeight,
                    widget.dirId,
                    widget.dirName,
                    UploadMode.MULTIPLE,
                    widget.fileType, (value) {
                  _imageList.addAll(value);
                  if (widget.valueChangedCallback != null) {
                    widget.valueChangedCallback!(_imageList);
                  }
                  setState(() {});
                });
              }
            },
            cloudCallback: () {
              Navigator.push(context, MaterialPageRoute(builder: (context) {
                return OnlineFilePage(
                  widget.dirId,
                  widget.dirName,
                  (result) {
                    setState(() {
                      if (result.isNotEmpty) {
                        result.forEach((element) {
                          _imageList.add(UploadResultEntity(
                              IPFSUtils.instance!
                                  .getFilePath(element.id, element.fileName),
                              "",
                              element.fileName));
                        });
                        if (widget.valueChangedCallback != null) {
                          widget.valueChangedCallback!(_imageList);
                        }
                        setState(() {});
                      }
                    });
                  },
                  fileType: widget.fileType,
                );
              }));
            },
          );
        });
  }

  // _showUploadDialog() {
  //   if (_showProgress) {
  //     return;
  //   }
  //   print("------ $_count");
  //   showGeneralDialog(
  //       context: context,
  //       barrierLabel: "",
  //       barrierColor: Colors.black.withOpacity(0.5),
  //       transitionDuration: const Duration(milliseconds: 500),
  //       barrierDismissible: true,
  //       pageBuilder: (BuildContext context, Animation animation,
  //           Animation secondaryAnimation) {
  //         return Scaffold(
  //           backgroundColor: Colors.transparent,
  //           body: Center(
  //             child: UploadProgressDialog(
  //               count: _count,
  //               total: _total,
  //             ),
  //           ),
  //         );
  //       });
  // }

  Widget _buildTopBtn() {
    return InkWell(
      child: Container(
        alignment: Alignment.center,
        width: double.infinity,
        padding: const EdgeInsets.symmetric(vertical: 15),
        margin: const EdgeInsets.only(top: 10, bottom: 10, right: 10),
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(3), color: Colors.blue),
        child: const Text(
          '选择图片',
          style: TextStyle(color: Colors.white, fontSize: 15),
        ),
      ),
      onTap: widget.isCanEdit
          ? () {
              _showPickerDialog();
            }
          : null,
    );
  }

  void _uploadImage() {
    IPFSUtils.instance!.imageUpload(context, (value) {
      _imageList.add(value);
      if (widget.valueChangedCallback != null) {
        widget.valueChangedCallback!(_imageList);
      }
      setState(() {});
    }, widget.dirId);
  }
}
